# -----------------
# Copyright © 2024 ACK Cyfronet AGH, Poland.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# This work was partially funded by DT-GEO Project.
# -----------------
def find_catalog_column(catalog, field_name):
    """
    Finds the index of a column in the catalog based on its field name.

    Parameters:
        catalog (np.ndarray): A structured NumPy array representing the catalog, where each row
                              corresponds to a field with attributes like 'field', 'val', etc.
        field_name (str): The field name of the entry to search for.

    Returns:
        int: The index of the entry matching the given field name.

    Raises:
        ValueError: If the specified field name is not found in the catalog.
    """
    for idx, col in enumerate(catalog):
        if col['field'] == field_name:
            return idx
    raise ValueError(f'No {field_name} field found in the catalog.')